@@ -158,48 +158,27 @@ def ascii_binary_to_vhdl_code(ascii_binary):
     def zero_pad(string, length):
         return string + "0" * max(length - len(string), 0)
 
-    print "library ieee;"
-    print "use ieee.std_logic_1164.all;"
-    print "use ieee.numeric_std.all;"
-    print ""
-    print "entity FakeInstMem is"
-    print "    port("
-    print "        IMEM_CE_HI      : in   STD_LOGIC;"
-    print "        IMEM_CE_LO      : in   STD_LOGIC;"
-    print "        IMEM_WE_HI      : in   STD_LOGIC;"
-    print "        IMEM_WE_LO      : in   STD_LOGIC;"
-    print "        IMEM_DATA_HI    : out STD_LOGIC_VECTOR(16-1 downto 0);"
-    print "        IMEM_DATA_LO    : out STD_LOGIC_VECTOR(16-1 downto 0);"
-    print "        IMEM_ADDR       : in   STD_LOGIC_VECTOR(19-1 downto 0);"
-    print "        IMEM_LBUB       : in   STD_LOGIC"
-    print "    );"
-    print "end FakeInstMem;"
-    print ""
-    print "architecture behavioral of FakeInstMem is"
-    print "type mem is array (0 to 2**19 - 1)",
+    number_of_instructions = len(ascii_binary)/32
+
+    print "type mem is array (0 to " + str(number_of_instructions) + ")",
     "of std_logic_vector(16-1 downto 0);"
     print ""
     print "constant hi : mem := ("
-    for i in range(2**19):
-        print "    " + str(i) + "  => \"" + \
+    print "    0 => \"0000000000000000\","
+    i = 0
+    for _ in range(number_of_instructions):
+        print "    " + str(i + 1) + "  => \"" + \
             zero_pad(ascii_binary[i * 32: i * 32 + 16], 16) + "\","
+        i += 1
+    print "    " + str(i + 1) + "  => \"0000000000000000\""
     print ");"
 
     print "constant lo : mem := ("
-    for i in range(2**19):
-        print "    " + str(i) + "  => \"" + \
+    print "    0 => \"0000000000000000\","
+    i = 0
+    for _ in range(number_of_instructions):
+        print "    " + str(i + 1) + "  => \"" + \
             zero_pad(ascii_binary[i * 32 + 16: i * 32 + 32], 16) + "\","
+        i += 1
+    print "    " + str(i + 1) + "  => \"0000000000000000\""
     print ");"
-    print ""
-    print "begin"
-    print ""
-    print "    process (address)"
-    print "    begin"
-    print "        case address is"
-    for i in range(2**19):
-        print "            when \"" + zero_pad(bin(i)[2:], 19) + \
-            "\" => data <= my_rom(" + str(i) + ");"
-    print "            when others => data <= \"" + ("0"*32) + "\";"
-    print "        end case;"
-    print "    end process;"
-    print "end architecture behavioral;"
